@@ -4,59 +4,16 @@
 #include <errno.h>
 #include <string.h>
 
+#include "util.h"
 #include "logging.h"
 #include "index.h"
 
-static char *getline_wrapped(FILE *file, unsigned int *linenum)
-{
-	int size = 256;
-	int i = 0;
-	char *buf = NOFAIL(malloc(size));
-	for(;;) {
-		int ch = getc_unlocked(file);
-		
-		switch(ch) {
-			case EOF:
-				if (i == 0) {
-					free(buf);
-					return NULL;
-				}
-				/* else fall through */
-			
-			case '\n':
-				if (linenum)
-					(*linenum)++;
-				if (i == size)
-					buf = NOFAIL(realloc(buf, size + 1));
-				buf[i] = '\0';
-				return buf;
-			
-			case '\\':
-				ch = getc_unlocked(file);
-			
-				if (ch == '\n') {
-					if (linenum)
-						(*linenum)++;
-					continue;
-				}
-				/* else fall through */
-		
-			default:
-				buf[i++] = ch;
-	
-				if (i == size) {
-					size *= 2;
-					buf = NOFAIL(realloc(buf, size));
-				}
-		}
-	}
-}
-
 static void write_index(const char *filename)
 {
 	struct index_node *index;
-	char *line;
+	char *line, *pos;
 	FILE *cfile;
+	unsigned int linenum = 0;
 	
 	cfile = fopen(filename, "w");
 	if (!cfile)
@@ -65,8 +22,10 @@ static void write_index(const char *filename)
 	
 	index = index_create();
 	
-	while((line = getline_wrapped(stdin, NULL))) {
-		index_insert(index, line);
+	while((line = getline_wrapped(stdin, &linenum))) {
+		pos = strchr(line, ' ');
+		*pos++ = '\0';
+		index_insert(index, line, pos, linenum);
 		free(line);
 	}
 	
@@ -75,65 +34,62 @@ static void write_index(const char *filename)
 	fclose(cfile);
 }
 
-static void dump_index(const char *filename)
+static struct index_file *open_index(const char *filename)
 {
-	FILE *cfile;
-	
-	cfile = fopen(filename, "r");
-	if (!cfile)
+	struct index_file *index;
+
+	index = index_file_open(filename);
+	if (!index) {
+		if (errno == EINVAL)
+			fatal("%s has wrong magic or version number", filename);
+
 		fatal("Could not open %s for reading: %s\n",
 		      filename, strerror(errno));
-	
-	index_dump(cfile, stdout, "");
-	
-	fclose(cfile);
+	}
+
+	return index;
+}
+
+static void dump_index(const char *filename)
+{
+	struct index_file *index = open_index(filename);
+
+	index_dump(index, stdout, "");
+
+	index_file_close(index);
 }
 
 static void search_index(const char *filename, char *key)
 {
+	struct index_file *index = open_index(filename);
 	char *value;
-	FILE *cfile;
-	
-	cfile = fopen(filename, "r");
-	if (!cfile)
-		fatal("Could not open %s for reading: %s\n",
-		      filename, strerror(errno));
-	
-	value = index_search(cfile, key);
+
+	value = index_search(index, key);
 	if (value)
 		printf("Found value:\n%s\n", value);
 	else
 		printf("Not found.\n");
 	
 	free(value);
-	fclose(cfile);
+	index_file_close(index);
 }
 
 static void searchwild_index(const char *filename, char *key)
 {
-	struct index_value *values;
-	FILE *cfile;
-	
-	cfile = fopen(filename, "r");
-	if (!cfile)
-		fatal("Could not open %s for reading: %s\n",
-		      filename, strerror(errno));
-	
-	values = index_searchwild(cfile, key);
+	struct index_file *index = open_index(filename);
+	struct index_value *values, *v;
+
+	values = index_searchwild(index, key);
 	if (values)
 		printf("Found value(s):\n");
 	else
-		printf("Not found.\n");
-	
-	while(values) {
-		struct index_value *next = values->next;
-		
-		printf("%s\n", values->value);
-		free(values);
-		values = next;
-	}
-	
-	fclose(cfile);
+		printf("Not found.\n");	
+
+	for (v = values; v; v = v->next)
+		printf("%s\n", v->value);
+
+	index_values_free(values);
+	index_file_close(index);
 }
 
 static void print_usage(const char *progname)
@@ -142,27 +98,27 @@ static void print_usage(const char *progname)
 		"Usage: %s [MODE] [FILE] ...\n"
 		" -o, --output <outfile>\n"
 		" -d, --dump <infile>\n"
-		" -s, --search <infile> <key>\n"
-		" -w, --searchwild <infile> <key>\n"
+		" -s, --search <key> <infile>\n"
+		" -w, --searchwild <key> <infile>\n"
 		,progname);
 	exit(1);
 }
 
-static struct option options[] = {
+static const struct option options[] = {
 	{ "output", 0, NULL, 'o' },
 	{ "dump", 0, NULL, 'd' },
-	{ "search", 0, NULL, 's' },
-	{ "searchwild", 0, NULL, 'w' },
+	{ "search", 1, NULL, 's' },
+	{ "searchwild", 1, NULL, 'w' },
 };
 
 int main(int argc, char *argv[])
 {
-	char opt;
+	int opt;
 	char mode = 0;
 	char *filename = NULL;
 	char *key = NULL;
 	
-	while ((opt = getopt_long(argc, argv, "odsw", options, NULL))
+	while ((opt = getopt_long(argc, argv, "ods:w:", options, NULL))
 		       != -1) {
 		switch (opt) {
 			case 'o':
@@ -173,9 +129,11 @@ int main(int argc, char *argv[])
 				break;
 			case 's':
 				mode = 's';
+				key = optarg;
 				break;
 			case 'w':
 				mode = 'w';
+				key = optarg;
 				break;
 			default:
 				print_usage(argv[0]);
@@ -188,12 +146,6 @@ int main(int argc, char *argv[])
 		print_usage(argv[0]);
 	filename = argv[optind];
 	
-	if (mode == 's' || mode == 'w') {
-		if (optind+1 >= argc)
-			print_usage(argv[0]);
-		key = argv[optind+1];
-	}
-	
 	switch(mode) {
 		case 'o':
 			write_index(filename);
